package com.mitchallen.testbook.test;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import org.junit.Ignore;
import org.junit.Test;

import com.mitchallen.testbook.custom.MyAnnotation;
import com.mitchallen.testbook.source.SourceTests;

public class ExampleTests {

	/**
	 * This test case demonstrate how a test runner like JUnit can read a test
	 * classes annotations (like @Test and @Ignore) and use that info to find
	 * tests methods, invoke them and find the cause of any errors.
	 * 
	 * @throws IllegalAccessException 
	 * @throws IllegalArgumentException 
	 */
	@Test
	public void testRunner() throws IllegalArgumentException, IllegalAccessException {

		// //////////////////////////////////////////////////////////////////////
		// Define the source test class that we will be parsing and running.
		
		SourceTests source = new SourceTests();

		for (Method m : SourceTests.class.getMethods()) {

			// //////////////////////////////////////////////
			// Process @MyAnnotation

			MyAnnotation myAnnotation = m.getAnnotation(MyAnnotation.class);

			if (myAnnotation != null) {
				
				System.out.println("---------------------------");

				System.out.println("MY ANNOTATION METHOD: " + m.getName());

				System.out.println(" ... VALUE = '" + myAnnotation.value() + "'");

			}

			// //////////////////////////////////////////////
			// Process @Test

			Test testMethod = m.getAnnotation(Test.class);

			if (testMethod != null) {

				System.out.println("---------------------------");
				System.out.println("TEST METHOD: " + m.getName());

				// //////////////////////////////////////////////
				// Process @Ignore

				Ignore ignoreMethod = m.getAnnotation(Ignore.class);

				if (ignoreMethod != null) {

					System.out.println(" ... IGNORE VALUE = '" + ignoreMethod.value() + "'");

				} else {

					try {

						m.invoke(source);	// Invoke the test case

						System.out.println(" ... PASS");

					} catch (InvocationTargetException e) {

						Throwable cause = e.getCause();

						System.out.println(" ... FAIL : CAUSE: '" + cause.getMessage() + "'");

						// e.printStackTrace();
						
					}
				}
			}
		}
	}

}
