package com.mitchallen.testbook.test;

import org.junit.Assert;
import org.junit.Test;

public class BadUsageTests {
	
	@Test public void genericFail() {
		
		int expect = 5;	// What we think it should be.
		int actual = 4;	// What it actually is.
		
		// BAD USAGE:
		// The code below should be replaced with:
		// Assert.assertEquals( "### ERROR - not equal: ", expect, actual );
		
		if( expect != actual ) {
		
			// This isn't very helpful.
			
			Assert.fail("Value not what expected");	
		}
	}
	
	@Test public void whichFail() {
		
		int a = 1, b = 1, c = 2, d = 1;
		
		if( a != b || b != c || c != d ) {
			
			// BAD USAGE:
			// Well which one didn't compare?
			// See next test for a better way
			
			Assert.fail( "Something didn't match" );
		}
	}
	
	@Test public void whichFailBetter() {
		
		int a = 1, b = 1, c = 2, d = 1;
		
		Assert.assertEquals( "### ERROR - not equal: (a,b): ", a, b );
		Assert.assertEquals( "### ERROR - not equal: (b,c): ", b, c );
		Assert.assertEquals( "### ERROR - not equal: (c,d): ", c, d );
	}

	
	@SuppressWarnings("unused")
	@Test public void overkillException() {
		
		int a = 5;
		int b = 0;
		
		// BAD USAGE:
		// No need to trap and fail test on exception
		// Junit will do that for you (see next example)
		
		try {
		
			int c = a / b;
			
		} catch( ArithmeticException ex ) {
			
			Assert.fail("Divide by zero");
		}
	}
	
	@SuppressWarnings("unused")
	@Test public void betterException() {
		
		int a = 5;
		int b = 0;
		
		// This will cause a divide by zero exception
		// The exception will be caught by junit and logged as an error
		
		int c = a / b;
	}
}
