package com.mitchallen.testbook.test;

import java.util.concurrent.TimeUnit;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.firefox.FirefoxDriver;
import org.openqa.selenium.support.PageFactory;

import com.mitchallen.common.Tools;
import com.mitchallen.testbook.model.google.HomePage;
import com.mitchallen.testbook.model.google.ResultsPage;

public class SearchTests {
	
	WebDriver driver = null;
	HomePage homePage = null;
	
	@Before public void setUp() {
		
		Tools.PrintMethodName();
		
		driver = new FirefoxDriver();
		
		Assert.assertNotNull( 
				"### ERROR: driver is null - is a recent version of Firefox installed?", 
				driver );
		
		driver.manage().timeouts().implicitlyWait(10, TimeUnit.SECONDS);
		
		// Set the base state for each test by navigating to the home page
		
		// Navigate to home page
		driver.get( "http://www.google.com" );
		
        // Create a new home page class and map the WebElements.
        homePage = PageFactory.initElements( driver, HomePage.class);
	}
	
	@After public void tearDown() {
		
		Tools.PrintMethodName();
		
		if( driver != null ) {
			
			driver.close();	// Close the instance of the browser
		}
		
		System.out.println( "-- ------------------------------------------" );
	}
	
	@Test public void testSearchFromHomePage() throws InterruptedException {
		
		Tools.PrintMethodName();	// Print name of this test case
				
        ResultsPage resultsPage = homePage.search( driver, "selenium" );
        
        // Fail if no results
        Assert.assertTrue( "### ERROR: result count is zero ", resultsPage.getResultCount() > 0 );
        
        resultsPage.dumpResults();
	}
	
	@Test public void testSearchCollection() throws InterruptedException {
		
		Tools.PrintMethodName();	// Print name of this test case
		
        ResultsPage resultsPage = homePage.search( driver, "selenium");
        
        int limit = resultsPage.getResultCount();
        
        for( int i = 0; i < limit; i++ ) {
        	
        	WebElement el = resultsPage.getResult( i );
        	
        	System.out.println( i + ": " + el.getText() );
        	System.out.println( "  ... " + el.getAttribute("href") );
        }   
	}
	
	@Test public void testSearchFromResultPage() throws InterruptedException {
		
		Tools.PrintMethodName();	// Print name of this test case
		
		// Search from the home page
        ResultsPage resultsPage = homePage.search( driver, "selenium");
             
        // Search from the results page
        resultsPage.search( driver, "test automation" );
        
        // Fail if no results
        Assert.assertTrue( "### ERROR: result count is zero ", resultsPage.getResultCount() > 0 );
        
        resultsPage.dumpResults();
	}

}
